@@ -5,9 +5,9 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 17, 35),
-    __version__='0.17.35',
-    version_timestamp='2023-10-04 11:45:09',
+    version_info=(0, 18, 0),
+    __version__='0.18.0',
+    version_timestamp='2023-10-23 20:55:25',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
@@ -16,7 +16,7 @@ _package_data = dict(
     extras_require={
         ':platform_python_implementation=="CPython" and python_version<"3.13"': ['ruamel.yaml.clib>=0.2.7'],  # NOQA
         'jinja2': ['ruamel.yaml.jinja2>=0.2'],
-        'docs': ['ryd'],
+        'docs': ['ryd', 'mercurial>5.7'],
     },
     classifiers=[
         'Programming Language :: Python :: 3 :: Only',
@@ -25,6 +25,7 @@ _package_data = dict(
         'Programming Language :: Python :: 3.9',
         'Programming Language :: Python :: 3.10',
         'Programming Language :: Python :: 3.11',
+        'Programming Language :: Python :: 3.12',
         'Programming Language :: Python :: Implementation :: CPython',
         'Topic :: Software Development :: Libraries :: Python Modules',
         'Topic :: Text Processing :: Markup',
